2011年3月6日日曜日

windows/linuxの再インストール; windows7 + debian6.0[squeeze]

承前:windows7のインストールは無線LAの設定でひっかかったものの、無事完了。しかしdebianの無線LANが・・・

さて有線だとルータの設定ができていればケーブル繋ぐだけでよいが、無線はセキュリティ設定もあり一筋縄ではいかない。
windowsではなんとかなったものの、debianが繋がらない。

なお使用PCのデバイスは次のもの。
intel wireless wifi link AGN5300

設定は以下の本とwebを参考にした。
1:debian wiki -iwlagn-
2:Intel Wireless Wifi Link driver for Linux
3:『改訂版Linuxコマンドポケットリファレンス』(技術評論社)

まずはシステムのネットワーク接続設定から無線LANのエントリを新規で作成。
WEPとWPA-PSKをそれぞれ作成。
またiwconfigコマンドでインターフェースにESSIDとキーを設定する。(WPAは使用するコマンドが違うらしいが、この時は気づかず。)
この時点ではドライバが読み込まれていないからか、無線ネットワークの一覧は見えていない。

続いてドライバのインストール。
参考1のsqueezeの項を参照し、そのままコマンドを打ち込んでいく。
aptitudeで関連ファイルをインストールしたあたりで、先程まで見えていなかったネットワークの一覧が表示された。
まだ自身のSSIDのネットワークは見えていない。
参考1-項目4のiwconfigの設定のところで、参考3のコマンドiwconfig(WEP用)とwpa_supplicant(WPA用)を参照し設定を行う。
参考1の手順を最後まで終えたところで接続確認をするものの、何度も認証を求められてどうしても繋がらない。

認証が通らないということはセキュリティの設定を間違えているということかと思うが。
そろそろ時間がないので次回検討にする。

※ネットワーク接続とターミナルのiwconfigから見た設定の関係についての疑問
システム=>設定=>ネットワーク接続:この一連の流れで行った無線LANの設定は、iwconfig wlan0コマンドからは見えていない。設定ファイルが違うということなのか。

出直し; ディスク管理は慎重に。

先日PCを再セットアップすることに。それから無線LANの設定がうまくいかずにげんなり。

ことの発端は3日前。
思うところあってwindows/linuxのデュアルブートを試みることにしたのだが、その過程でブートセクタを削除してしまった模様。debianのインストールディスクからドライブの構成を見ると、基本パーティションが4つあり追加スペースを確保できない状態だったので調べてみることに。

windows7の管理画面からディスクの管理を確認したところ、パーティションが3つほど見えていた。
=>プライマリ2.7G(回復パーティション)
 基本パーティション(詳細は忘れた) => CドライブとDドライブ(1つの物理ディスクを分割)

再度インストールディスクからディスクの状態を確認したところ、windows上から見えていない1MB程度のスペースがあった。これはブートセクタだろう。

回復パーティションはおそらくノートPCにプリセット?されているドライバ類などの復旧用データだろうと思い、ここは削除可能と踏んで削除することに。
削除に先立ってドライブの空きスペースを調整するべくwindows7のディスク管理からディスク縮小を行ったところ、いくつかのスペースのステータスが基本パーティションから変更されてしまった。(内容は既にうろ覚えだが、縮小前にアラートが表示されていたのでそのメッセージの記録を取っておくべきだった。ブートに関係する注意事項だったように思う・・・)

削除後にdebian[squeeze]のインストールを行ったのち、grubからwindowsを起動しようとしたところ、復旧シークエンスに移行。嫌な予感がしたが時既に遅く。復旧ツールの起動が完了し、再起動後再度windowsを起動・・・できない。

ということであっさり諦めて全部インストールし直すことにした。

2011年3月2日水曜日

Ruby; windowsに逃避

先日までLinux上で開発環境を整えていたところから逃げをうって、しばらくWindowsで学習することに。
LinuxはVMplayerで動かしているので、画面全体を使いきれておらず挙動も重いとあって億劫になってきたのです。
そのうち専用マシンを組んであげたいなぁ。

さて話はwindowsでの環境に移って、こちらは以前からMySQLとRuby1.9.2がセットアップされている。またRailsもインストールされている。

今回はRubyのシンボルの使い方についてメモ。
調べた中では『Ruby逆引きハンドブック』の説明が一番詳しいと思うが、どうもピンとこない。
とりあえずハッシュのキーとして使用する方法に慣れるのが先か。

以下のソースはOpen-uriライブラリからの抜粋。

module OpenURI
Options = {
:proxy => true,
:proxy_http_basic_authentication => true,
:progress_proc => true,
:content_length_proc => true,
:http_basic_authentication => true,
:read_timeout => true,
:ssl_ca_cert => nil,
:ssl_verify_mode => nil,
:ftp_active_mode => false,
:redirect => true,
}

def OpenURI.check_options(options) # :nodoc:
options.each {|k, v|
next unless Symbol === k
unless Options.include? k
raise ArgumentError, "unrecognized option: #{k}"
end
}
end
.
.
(略)
end

2011年2月23日水曜日

Linux環境を整える4;

MySQL Workbenchをインストールする。Linux用のソースコードからコンパイルすることに。
 /tar xzvf mysql-workbench...(略) => ok
 /make => NG(makefileが見つからない)
前回までの例から、configureが必要なようなので試す。
 /./configure => no package libzip found
何かエラーが出たので調べてみると、どうもlibzipというzipファイルを操作するためのcライブラリがあるらしい。
適当にパッケージを探してみる。
 /apt-cache search libzip (aptitude search libzip) => 結果は実表示を参照のこと。
とりあえずlibzip1というファイルをインストールしてみる。
 /apt-get install libzip1
再度configureを試す。
 /./configure => no package libzip found
aptitudeで状態確認してもlibzip1のインストールは確認できているので、まだ調査が必要そう。
いったん中断。

2011年2月20日日曜日

Linux環境を整える3; Ruby1.9にバージョンアップする

さらに続き。

■Ruby ver1.9.2のアーカイブを取得し展開。
 tar xzvf ruby...(略) => cd 展開されたディレクトリ
 ./configure --prefix=/usr/local/ruby => $PATHにCコンパイラがないと怒られた。
/gccというライブラリが利用できそうなことが分かったので、取り合えずaptしてみる。
 apt-get install gcc => dpkg --list gcc => 見つかりません。再度試してみる。
 apt-get install gcc => libc6などいくつかのファイルが置換され、何らかのサービスのrestartを促す画面が表示された。ちょっと不安がよぎるが・・・。
 dpkg --list gcc => 4.4.5-1
/無事gccはインストールされたので、再びconfigureを実行
 ./configure --prefix=/usr/local/ruby => メッセージからMakefileの作成がなされたと思われる。
/makeを実行
 make => ok(コンパイル?されたファイルの統計が表示)
 make install => ok
/rubyのインストール確認
 ruby -v => ファイルが見つかりません。どうやらpathを通してないらしい
 /usr/local/ruby/bin/ruby -v => ruby-1.9.2-p180
/irb1.9
 irb => p VERSION => 1.8.7(irbは別にバージョンアップが必要か)
 aptitude install irb1.9 => irb => p VERSION => 1.8.7
aptitudeのsearchによると、irb1.9はインストールされている。
irbコマンドに関連付けられているバージョンを1.9に変更する必要があると思われる。

■次回作業用のメモ
・システム
 mysql用ユーザの認証ができない件を解消
・Ruby
 irbコマンドの1.9関連付け
・MySQL
 データベース使用ユーザの作成
 workbenchのインストール

Linux環境を整える2; MySQL => PostgreSQL => ?

先日の続き。

■MySQLのインストール...の筈が。
/MySQL(ver5.1.55)のtarアーカイブをダウンロードし、展開
 tar xzvf mysql-(version)-(os)...略
/インストール準備(makeが居るらしいがインストールされていなかったので、先にapt-getでmakeをインストール)
 apt-get install make => su root => which make => /usr/bin/make
/configureスクリプトで初期設定
 ./configure --prefix=/usr/local/mysql => スクリプトが見つかりません。

※何やらconfigureが見つからないということで、先にmakeを試してみたり、別のバージョンを落としてみたものの、それぞれmakefileがないので不可、同じくconfigureが見つからないので不可、と上手くいかず。

/rpmで試してみる(.rpmパッケージファイルを取得)
 rpm -i mysql-5.1.55..(略) => 依存ファイルが大量にあるらしく、そのままではインストールできず。

■postgresに浮気してみる。
/mysqlと同じようにtarを取得して展開=>今度はconfigureは機能はしたもののエラーが出て不完全な状態なのか、その後のmakeまでは進めず。次にdpkgを試す。
/OpenSCG(http://www.openscg.org/se/)からdebパッケージファイルを取得。
 dpkg -i postgres-9.0 => ok
 dpkg -s => Statusは"install ok"
 dpkg -L => /opt以下にファイルがあることを確認。
/日本語マニュアルを参照し、createdbするもコマンド見つからずのエラー。新規ユーザーを作成し、権限を移譲してみるが、それでは無理の様子。
 cd /opt/postgres/...(略)/bin (createdbコマンドがあるディレクトリ)
 su root => useradd pgsql => groupadd pgsql => cd /opt => chown -R pgsql ./postgres => chgrp -R pgsql ./postgres

おおよその経過は以上。さて、どうするか。

■apt-getを使用し、MySQLのインストールに再度挑戦
 apt-get install mysql => パッケージが見つからない。
 apt-get install mysql-server => ok(パッケージ名を知る方法はあるのだろうか)
/インストールされているかを確認する方法を模索。
 dpkg --list => パッケージが見つかりません。
 aptitude search mysql(Linuxコマンドポケットリファレンスの使用例を元にした) => 関連パッケージが大量に表示。またmysql-serverほか、clientファイルなどの状態を示すフラグが未インストール(=p)となっていることを確認。
 apt-get install -s mysql-server => インストールされるパッケージ一覧を表示。
/ダメもとでapt-getを再度実行
 apt-get install mysql-server => 今度はrootパスワードの設定画面などが表示された。上手く行った?
/パッケージ確認
 dpkg --list mysql-server => ver 5.1.49
 aptitude search mysql => mysql-server, client(ver5.1)など最低限のものはインストールされた模様。
 which mysql => /usr/bin/mysql

■何とかインストールできたので、とりあえず起動してみる。
 mysql => denied(rootユーザーでもダメ?)
/MySQL全機能バイブルによれば起動方法は2つあるとのことで、ここではmysqld_safeを試してみる。
 mysqld_safe => process already exists(どうもインストール後そのまま起動している様子)
 mysql -u (root) -p => "enter password"(-pオプションが必要だったらしい)

■管理者用に作ったシステムアカウントにログインできない
suでログインを試みたが、上手くいかない。usermodでパスの変更なども試したが、同じ結果。

■不要になったpostgreSQLの削除
 dpkg -P postgres-9.0 => ok(-rは設定ファイルを残す(=remove)、-Pは全て削除(=purge))
 ls /opt => インストール時に作成されていたディレクトリごと削除完了。

■関連フォルダは以下の通り
 /usr/bin/mysql(whichのパス)
 /etc/bin/mysql(設定関連の保存フォルダ)

2011年2月19日土曜日

Linux環境を整える;Ruby, MySQL

VMPlayerでDebian GNU Linuxを導入してからLPICの勉強を細々と続けていたが、脱線しっ放しで未だ取得の見込みが立たず。
最近はRubyとHTML・CSS・JavaScriptの間を行ったり来たりしてきている。Windows環境ではインストーラ一つで何かと済ませられることが多いものの、Linuxを使っていこうと思ったらコマンドラインにも習熟しないとならない。

そんな訳で仮想マシン上のDebianにRubyとMySQLをインストールし開発環境の下地を作りたい。
以下、作業メモ。

・Rubyのインストール確認
 dpkg --list Ruby => version 4.2(debパッケージファイルのバージョンNo?)。
・irbのインストール確認
 dpkg --list irb => パッケージ見つからず。
・dpkgコマンドだとコアが1.8.7と思われる(公式によると)ので、aptで最新版が利用できないか試す。
 公式を参考に、'/etc/apt/sources.list'ファイルに以下の2行を追加。
 deb ftp://ftp.debian.org/debian unstable main
 deb-src ftp://ftp.debian.org/debian unstable main
 (aptが拾ってくるパッケージ情報のソースを追加するものと思われる。通称アプトライン(らしい))
・エディタgeditで当該ファイルの更新を行おうとしたところ、権限がないため拒否される。ファイルの権限変更を試みる。
 cd /etc/apt => ls -l(permission確認) => chmod 666 sources.list => うまくいかず。
 (terminalから) gedit sources.list => 編集可能となったため、先述の2行を追加。
・aptの実行とdpkgによるバージョン確認
 apt-get install ruby => apt-get update
 dpkg --list ruby => verson 4.5
 dpkg --list irb => version 4.2(irb起動しVERSIONを表示=>1.8.7)
・ひとまずMySQLのインストールに移行
 (以下、「MySQL全機能バイブル」を参考に実施)
 groupadd mysql
 useradd -m mysql -g mysql -d /home/mysql
 passwd mysql => "enter new password" mysql => "retype" mysql => "success"

ダウンロードに時間がかかったので続きは翌日。